@@ -19,7 +19,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 import queue
-from PySide2 import QtCore, QtWidgets, QtGui
+from PySide6 import QtCore, QtWidgets, QtGui
 
 from onionshare_cli.onionshare import OnionShare
 from onionshare_cli.web import Web
@@ -38,12 +38,18 @@ from ..widgets import Alert
 
 
 class NewTabButton(QtWidgets.QPushButton):
-    def __init__(self, common, image_filename, title, text):
+    def __init__(self, common, image_filename, title, text, shortcut):
         super(NewTabButton, self).__init__()
         self.common = common
 
         self.setFixedSize(280, 280)
 
+        # Keyboard shortcut, using the first letter of the mode
+        sequence = QtGui.QKeySequence(QtCore.Qt.CTRL | shortcut)
+        self.setShortcut(sequence)
+
+        self.setAccessibleName(title)
+
         # Image
         self.image_label = QtWidgets.QLabel(parent=self)
         self.image_label.setPixmap(
@@ -140,6 +146,7 @@ class Tab(QtWidgets.QWidget):
             "images/{}_mode_new_tab_share.png".format(self.common.gui.color_mode),
             strings._("gui_new_tab_share_button"),
             strings._("gui_main_page_share_button"),
+            QtCore.Qt.Key_S,
         )
         self.share_button.clicked.connect(self.share_mode_clicked)
 
@@ -148,6 +155,7 @@ class Tab(QtWidgets.QWidget):
             "images/{}_mode_new_tab_receive.png".format(self.common.gui.color_mode),
             strings._("gui_new_tab_receive_button"),
             strings._("gui_main_page_receive_button"),
+            QtCore.Qt.Key_R,
         )
         self.receive_button.clicked.connect(self.receive_mode_clicked)
 
@@ -156,6 +164,7 @@ class Tab(QtWidgets.QWidget):
             "images/{}_mode_new_tab_website.png".format(self.common.gui.color_mode),
             strings._("gui_new_tab_website_button"),
             strings._("gui_main_page_website_button"),
+            QtCore.Qt.Key_W,
         )
         self.website_button.clicked.connect(self.website_mode_clicked)
 
@@ -164,6 +173,7 @@ class Tab(QtWidgets.QWidget):
             "images/{}_mode_new_tab_chat.png".format(self.common.gui.color_mode),
             strings._("gui_new_tab_chat_button"),
             strings._("gui_main_page_chat_button"),
+            QtCore.Qt.Key_C,
         )
         self.chat_button.clicked.connect(self.chat_mode_clicked)
 
@@ -620,20 +630,6 @@ class Tab(QtWidgets.QWidget):
         else:
             return None
 
-    def settings_have_changed(self):
-        # Global settings have changed
-        self.common.log("Tab", "settings_have_changed")
-
-        # We might've stopped the main requests timer if a Tor connection failed. If we've reloaded
-        # settings, we probably succeeded in obtaining a new connection. If so, restart the timer.
-        if not self.common.gui.local_only:
-            if self.common.gui.onion.is_authenticated():
-                mode = self.get_mode()
-                if mode:
-                    if not self.timer.isActive():
-                        self.timer.start(500)
-                    mode.on_reload_settings()
-
     def close_tab(self):
         self.common.log("Tab", "close_tab")
         if self.mode is None:
@@ -650,13 +646,15 @@ class Tab(QtWidgets.QWidget):
                     dialog_text = strings._("gui_close_tab_warning_share_description")
                 elif self.mode == self.common.gui.MODE_RECEIVE:
                     dialog_text = strings._("gui_close_tab_warning_receive_description")
+                elif self.mode == self.common.gui.MODE_CHAT:
+                    dialog_text = strings._("gui_close_tab_warning_chat_description")
                 else:
                     dialog_text = strings._("gui_close_tab_warning_website_description")
 
         # Open the warning dialog
         self.common.log("Tab", "close_tab, opening warning dialog")
         self.close_dialog.setText(dialog_text)
-        self.close_dialog.exec_()
+        self.close_dialog.exec()
 
         # Close
         if self.close_dialog.clickedButton() == self.close_dialog.accept_button:
